library(testthat)
library(splithalfr)

#test_check("splithalfr")
